export declare class RandomVar {
    protected _seed: number | null;
    constructor(seed?: number | null);
    sample(): number;
}
export declare class Uniform extends RandomVar {
    protected _min: number;
    protected _max: number;
    constructor(min: number, max: number, seed?: number);
    get min(): number;
    get max(): number;
    sample(): number;
}
export declare class Triangular extends RandomVar {
    _min: number;
    _peak: number;
    _max: number;
    constructor(min: number, mode: number, max: number, seed?: number);
    get min(): number;
    get mode(): number;
    get max(): number;
    sample(): number;
}
export declare class Empirical extends RandomVar {
    protected _xVals: number[];
    protected _yVals: number[];
    constructor(xVals: number[], yVals: number[], seed?: number);
    get xVals(): number[];
    get yVals(): number[];
    sample(): number;
}
export declare class Exponential extends RandomVar {
    protected _mean: number;
    constructor(mean: number, seed?: number);
    get mean(): number;
    sample(): number;
}
export declare class Erlang extends Exponential {
    protected _shape: number;
    constructor(shape: number, scale: number, seed?: number);
    get shape(): number;
    get scale(): number;
    sample(): number;
}
export declare class Gamma extends RandomVar {
    _shape: number;
    _scale: number;
    constructor(shape: number, scale: number, seed?: number);
    get shape(): number;
    get scale(): number;
    sample(): number;
}
export declare class Normal extends RandomVar {
    protected _mean: number;
    protected _std: number;
    protected _n1: number;
    protected _positive: boolean;
    constructor(mean: number, std: number, positive?: boolean, seed?: number);
    get mean(): number;
    get std(): number;
    sample(): number;
}
export declare class LogNormal extends Normal {
    protected _lnMean: number;
    protected _lnStd: number;
    constructor(mean: number, std: number, seed?: number);
    get mean(): number;
    get std(): number;
    sample(): number;
}
export declare class RandomInt extends RandomVar {
    protected _max: number;
    constructor(max: number, seed?: number);
    get max(): number;
    sample(): number;
}
